## -*- coding: utf-8 -*- %if c.repo_changesets:

${_('Revision')} | ${_('Commit message')} | ${_('Age')} | ${_('Author')} | ${_('Refs')}
--- | --- | --- | --- | ---
%for cnt,cs in enumerate(c.repo_changesets):
%if c.statuses.get(cs.raw_id): %if c.statuses.get(cs.raw_id)[2]: %else: %endif %endif %if c.comments.get(cs.raw_id,[]): ${len(c.comments[cs.raw_id])} %endif
    ${h.show_id(cs)}
| ${h.urlify_commit(h.truncate(cs.message,50),c.repo_name, h.url('changeset_home',repo_name=c.repo_name,revision=cs.raw_id))} | ${h.age(cs.date)} | ${h.person(cs.author)} | %if h.is_hg(c.db_repo_scm_instance): %for book in cs.bookmarks: ${h.link_to(book,h.url('changeset_home',repo_name=c.repo_name,revision=cs.raw_id))} %endfor %endif %for tag in cs.tags: ${h.link_to(tag,h.url('changeset_home',repo_name=c.repo_name,revision=cs.raw_id))} %endfor %if cs.branch: ${h.link_to(cs.branch,h.url('changelog_home',repo_name=c.repo_name,branch=cs.branch))} %endif
%endfor

${c.repo_changesets.pager('$link_previous ~2~ $link_next')}
%else: %if h.HasRepoPermissionAny('repository.write','repository.admin')(c.repo_name):

#### ${_('Add or upload files directly via Kallithea')}

${_('Add New File')}
%endif

#### ${_('Push new repo')}

        ${c.db_repo_scm_instance.alias} clone ${c.clone_repo_url}
        ${c.db_repo_scm_instance.alias} add README # add first file
        ${c.db_repo_scm_instance.alias} commit -m "Initial" # commit with message
        ${c.db_repo_scm_instance.alias} push ${'origin master' if h.is_git(c.db_repo_scm_instance) else ''} # push changes back

#### ${_('Existing repository?')}

    %if h.is_git(c.db_repo_scm_instance):
        git remote add origin ${c.clone_repo_url}
        git push -u origin master
    %else:
        hg push ${c.clone_repo_url}
    %endif

%endif